@@ -35,8 +35,6 @@ def _stub_volume(**kwargs):
         "bootable": "false",
         "availability_zone": "cinder",
         "created_at": "2012-08-27T00:00:00.000000",
-        "display_description": None,
-        "display_name": None,
         "id": '00000000-0000-0000-0000-000000000000',
         "metadata": {},
         "size": 1,
@@ -260,6 +258,9 @@ class FakeHTTPClient(base_client.HTTPClient):
     def get_snapshots_1234(self, **kw):
         return (200, {}, {'snapshot': _stub_snapshot(id='1234')})
 
+    def get_snapshots_5678(self, **kw):
+        return (200, {}, {'snapshot': _stub_snapshot(id='5678')})
+
     def put_snapshots_1234(self, **kw):
         snapshot = _stub_snapshot(id='1234')
         snapshot.update(kw['body']['snapshot'])
@@ -278,6 +279,12 @@ class FakeHTTPClient(base_client.HTTPClient):
             raise AssertionError("Unexpected action: %s" % action)
         return (resp, {}, _body)
 
+    def post_snapshots_5678_action(self, body, **kw):
+        return self.post_snapshots_1234_action(body, **kw)
+
+    def delete_snapshots_1234(self, **kw):
+        return (202, {}, {})
+
     #
     # Volumes
     #
@@ -351,6 +358,9 @@ class FakeHTTPClient(base_client.HTTPClient):
             raise AssertionError("Unexpected action: %s" % action)
         return (resp, {}, _body)
 
+    def post_volumes_5678_action(self, body, **kw):
+        return self.post_volumes_1234_action(body, **kw)
+
     def post_volumes(self, **kw):
         return (202, {}, {'volume': {}})
 
@@ -468,6 +478,9 @@ class FakeHTTPClient(base_client.HTTPClient):
     def put_types_1_encryption_1(self, body, **kw):
         return (200, {}, {})
 
+    def delete_types_1_encryption_provider(self, **kw):
+        return (202, {}, None)
+
     #
     # Set/Unset metadata
     #
@@ -689,11 +702,11 @@ class FakeHTTPClient(base_client.HTTPClient):
 
     def put_os_services_enable(self, body, **kw):
         return (200, {}, {'host': body['host'], 'binary': body['binary'],
-                'status': 'disabled'})
+                'status': 'enabled'})
 
     def put_os_services_disable(self, body, **kw):
         return (200, {}, {'host': body['host'], 'binary': body['binary'],
-                'status': 'enabled'})
+                'status': 'disabled'})
 
     def get_os_availability_zone(self, **kw):
         return (200, {}, {
