@@ -86,7 +86,7 @@ class ShellTest(utils.TestCase):
 
         for input in inputs:
             args = Arguments(metadata=input[0])
-            self.assertEquals(shell_v1._extract_metadata(args), input[1])
+            self.assertEqual(shell_v1._extract_metadata(args), input[1])
 
     def test_list(self):
         self.run_command('list')
@@ -124,6 +124,7 @@ class ShellTest(utils.TestCase):
 
     def test_delete_multiple(self):
         self.run_command('delete 1234 5678')
+        self.assert_called_anytime('DELETE', '/volumes/1234')
         self.assert_called('DELETE', '/volumes/5678')
 
     def test_backup(self):
@@ -211,6 +212,14 @@ class ShellTest(utils.TestCase):
         expected = {'os-reset_status': {'status': 'error'}}
         self.assert_called('POST', '/volumes/1234/action', body=expected)
 
+    def test_reset_state_multiple(self):
+        self.run_command('reset-state 1234 5678 --state error')
+        expected = {'os-reset_status': {'status': 'error'}}
+        self.assert_called_anytime('POST', '/volumes/1234/action',
+                                   body=expected)
+        self.assert_called_anytime('POST', '/volumes/5678/action',
+                                   body=expected)
+
     def test_snapshot_reset_state(self):
         self.run_command('snapshot-reset-state 1234')
         expected = {'os-reset_status': {'status': 'available'}}
@@ -221,6 +230,14 @@ class ShellTest(utils.TestCase):
         expected = {'os-reset_status': {'status': 'error'}}
         self.assert_called('POST', '/snapshots/1234/action', body=expected)
 
+    def test_snapshot_reset_state_multiple(self):
+        self.run_command('snapshot-reset-state 1234 5678')
+        expected = {'os-reset_status': {'status': 'available'}}
+        self.assert_called_anytime('POST', '/snapshots/1234/action',
+                                   body=expected)
+        self.assert_called_anytime('POST', '/snapshots/5678/action',
+                                   body=expected)
+
     def test_encryption_type_list(self):
         """
         Test encryption-type-list shell command.
@@ -275,8 +292,14 @@ class ShellTest(utils.TestCase):
     def test_encryption_type_delete(self):
         """
         Test encryption-type-delete shell command.
+
+        Verify one GET/one DELETE requests are made per command invocation:
+        - one GET request to retrieve the relevant volume type information
+        - one DELETE request to delete the encryption type information
         """
-        self.skipTest("Not implemented")
+        self.run_command('encryption-type-delete 1')
+        self.assert_called('DELETE', '/types/1/encryption/provider')
+        self.assert_called_anytime('GET', '/types/1')
 
     def test_migrate_volume(self):
         self.run_command('migrate 1234 fakehost --force-host-copy=True')
@@ -318,3 +341,17 @@ class ShellTest(utils.TestCase):
         self.run_command('readonly-mode-update 1234 False')
         expected = {'os-update_readonly_flag': {'readonly': False}}
         self.assert_called('POST', '/volumes/1234/action', body=expected)
+
+    def test_service_disable(self):
+        self.run_command('service-disable host cinder-volume')
+        self.assert_called('PUT', '/os-services/disable',
+                           {"binary": "cinder-volume", "host": "host"})
+
+    def test_service_disable(self):
+        self.run_command('service-enable host cinder-volume')
+        self.assert_called('PUT', '/os-services/enable',
+                           {"binary": "cinder-volume", "host": "host"})
+
+    def test_snapshot_delete(self):
+        self.run_command('snapshot-delete 1234')
+        self.assert_called('DELETE', '/snapshots/1234')
