@@ -267,6 +267,9 @@ class FakeHTTPClient(base_client.HTTPClient):
     def get_snapshots_1234(self, **kw):
         return (200, {}, {'snapshot': _stub_snapshot(id='1234')})
 
+    def get_snapshots_5678(self, **kw):
+        return (200, {}, {'snapshot': _stub_snapshot(id='5678')})
+
     def put_snapshots_1234(self, **kw):
         snapshot = _stub_snapshot(id='1234')
         snapshot.update(kw['body']['snapshot'])
@@ -285,6 +288,12 @@ class FakeHTTPClient(base_client.HTTPClient):
             raise AssertionError('Unexpected action: %s' % action)
         return (resp, {}, _body)
 
+    def post_snapshots_5678_action(self, body, **kw):
+        return self.post_snapshots_1234_action(body, **kw)
+
+    def delete_snapshots_1234(self, **kw):
+        return (202, {}, {})
+
     #
     # Volumes
     #
@@ -354,10 +363,15 @@ class FakeHTTPClient(base_client.HTTPClient):
             assert 'force_host_copy' in body[action]
         elif action == 'os-update_readonly_flag':
             assert list(body[action]) == ['readonly']
+        elif action == 'os-retype':
+            assert 'new_type' in body[action]
         else:
             raise AssertionError("Unexpected action: %s" % action)
         return (resp, {}, _body)
 
+    def post_volumes_5678_action(self, body, **kw):
+        return self.post_volumes_1234_action(body, **kw)
+
     def post_volumes(self, **kw):
         return (202, {}, {'volume': {}})
 
@@ -475,6 +489,9 @@ class FakeHTTPClient(base_client.HTTPClient):
     def put_types_1_encryption_1(self, body, **kw):
         return (200, {}, {})
 
+    def delete_types_1_encryption_provider(self, **kw):
+        return (202, {}, None)
+
     #
     # Set/Unset metadata
     #
@@ -697,11 +714,11 @@ class FakeHTTPClient(base_client.HTTPClient):
 
     def put_os_services_enable(self, body, **kw):
         return (200, {}, {'host': body['host'], 'binary': body['binary'],
-                'status': 'disabled'})
+                'status': 'enabled'})
 
     def put_os_services_disable(self, body, **kw):
         return (200, {}, {'host': body['host'], 'binary': body['binary'],
-                'status': 'enabled'})
+                'status': 'disabled'})
 
     def get_os_availability_zone(self, **kw):
         return (200, {}, {
