@@ -1,4 +1,4 @@
-# Copyright 2013 OpenStack LLC
+# Copyright (c) 2013 OpenStack Foundation
 # All Rights Reserved.
 #
 #    Licensed under the Apache License, Version 2.0 (the "License"); you may
@@ -16,12 +16,14 @@
 from cinderclient import client
 from cinderclient.v1 import availability_zones
 from cinderclient.v1 import limits
+from cinderclient.v1 import qos_specs
 from cinderclient.v1 import quota_classes
 from cinderclient.v1 import quotas
 from cinderclient.v1 import services
 from cinderclient.v1 import volumes
 from cinderclient.v1 import volume_snapshots
 from cinderclient.v1 import volume_types
+from cinderclient.v1 import volume_encryption_types
 from cinderclient.v1 import volume_backups
 from cinderclient.v1 import volume_backups_restore
 from cinderclient.v1 import volume_transfers
@@ -59,6 +61,9 @@ class Client(object):
         self.volumes = volumes.VolumeManager(self)
         self.volume_snapshots = volume_snapshots.SnapshotManager(self)
         self.volume_types = volume_types.VolumeTypeManager(self)
+        self.volume_encryption_types = \
+            volume_encryption_types.VolumeEncryptionTypeManager(self)
+        self.qos_specs = qos_specs.QoSSpecsManager(self)
         self.quota_classes = quota_classes.QuotaClassSetManager(self)
         self.quotas = quotas.QuotaSetManager(self)
         self.backups = volume_backups.VolumeBackupManager(self)
