@@ -61,7 +61,7 @@ class RateLimit(object):
             and self.next_available == other.next_available
 
     def __repr__(self):
-        return "<RateLimit: method=%s uri=%s>" % (self.method, self.uri)
+        return "<RateLimit: method=%s uri=%s>" % (self.verb, self.uri)
 
 
 class AbsoluteLimit(object):
