@@ -339,7 +339,7 @@ def do_force_delete(cs, args):
                                       "specified volumes.")
 
 
-@utils.arg('volume', metavar='<volume>',
+@utils.arg('volume', metavar='<volume>', nargs='+',
            help='Name or ID of the volume to modify.')
 @utils.arg('--state', metavar='<state>', default='available',
            help=('Indicate which state to assign the volume. Options include '
@@ -348,8 +348,23 @@ def do_force_delete(cs, args):
 @utils.service_type('volumev2')
 def do_reset_state(cs, args):
     """Explicitly update the state of a volume."""
-    volume = utils.find_volume(cs, args.volume)
-    volume.reset_state(args.state)
+    failure_count = 0
+
+    single = (len(args.volume) == 1)
+
+    for volume in args.volume:
+        try:
+            utils.find_volume(cs, volume).reset_state(args.state)
+        except Exception as e:
+            failure_count += 1
+            msg = "Reset state for volume %s failed: %s" % (volume, e)
+            if not single:
+                print(msg)
+
+    if failure_count == len(args.volume):
+        if not single:
+            msg = "Unable to reset the state for any of the specified volumes."
+        raise exceptions.CommandError(msg)
 
 
 @utils.arg('volume',
@@ -556,7 +571,7 @@ def do_snapshot_rename(cs, args):
     _find_volume_snapshot(cs, args.snapshot).update(**kwargs)
 
 
-@utils.arg('snapshot', metavar='<snapshot>',
+@utils.arg('snapshot', metavar='<snapshot>', nargs='+',
            help='Name or ID of the snapshot to modify.')
 @utils.arg('--state', metavar='<state>',
            default='available',
@@ -567,8 +582,24 @@ def do_snapshot_rename(cs, args):
 @utils.service_type('volumev2')
 def do_snapshot_reset_state(cs, args):
     """Explicitly update the state of a snapshot."""
-    snapshot = _find_volume_snapshot(cs, args.snapshot)
-    snapshot.reset_state(args.state)
+    failure_count = 0
+
+    single = (len(args.snapshot) == 1)
+
+    for snapshot in args.snapshot:
+        try:
+            _find_volume_snapshot(cs, snapshot).reset_state(args.state)
+        except Exception as e:
+            failure_count += 1
+            msg = "Reset state for snapshot %s failed: %s" % (snapshot, e)
+            if not single:
+                print(msg)
+
+    if failure_count == len(args.snapshot):
+        if not single:
+            msg = ("Unable to reset the state for any of the the specified "
+                   "snapshots.")
+        raise exceptions.CommandError(msg)
 
 
 def _print_volume_type_list(vtypes):
@@ -839,7 +870,7 @@ def _find_volume_type(cs, vtype):
            default='raw')
 @utils.arg('--disk_format',
            help=argparse.SUPPRESS)
-@utils.arg('image-name',
+@utils.arg('image_name',
            metavar='<image-name>',
            help='Name for created image')
 @utils.arg('--image_name',
@@ -869,6 +900,19 @@ def do_migrate(cs, args):
     volume.migrate_volume(args.host, args.force_host_copy)
 
 
+@utils.arg('volume', metavar='<volume>',
+           help='Name or ID of the volume to retype')
+@utils.arg('new_type', metavar='<volume-type>', help='New volume type')
+@utils.arg('--migration-policy', metavar='<never|on-demand>', required=False,
+           choices=['never', 'on-demand'], default='never',
+           help='Policy on migrating the volume during the retype.')
+@utils.service_type('volumev2')
+def do_retype(cs, args):
+    """Change the volume's type."""
+    volume = utils.find_volume(cs, args.volume)
+    volume.retype(args.new_type, args.migration_policy)
+
+
 @utils.arg('volume', metavar='<volume>',
            help='Name or ID of the volume to backup.')
 @utils.arg('--container', metavar='<container>',
@@ -1029,7 +1073,7 @@ def do_transfer_show(cs, args):
 
 @utils.arg('volume', metavar='<volume>',
            help='Name or ID of the volume to extend.')
-@utils.arg('new-size',
+@utils.arg('new_size',
            metavar='<new_size>',
            type=int,
            help='New size of volume in GB')
@@ -1057,7 +1101,9 @@ def do_service_list(cs, args):
 @utils.service_type('volumev2')
 def do_service_enable(cs, args):
     """Enable the service."""
-    cs.services.enable(args.host, args.binary)
+    result = cs.services.enable(args.host, args.binary)
+    columns = ["Host", "Binary", "Status"]
+    utils.print_list([result], columns)
 
 
 @utils.arg('host', metavar='<hostname>', help='Name of host.')
@@ -1065,7 +1111,9 @@ def do_service_enable(cs, args):
 @utils.service_type('volumev2')
 def do_service_disable(cs, args):
     """Disable the service."""
-    cs.services.disable(args.host, args.binary)
+    result = cs.services.disable(args.host, args.binary)
+    columns = ["Host", "Binary", "Status"]
+    utils.print_list([result], columns)
 
 
 def _treeizeAvailabilityZone(zone):
@@ -1211,6 +1259,17 @@ def do_encryption_type_create(cs, args):
     _print_volume_encryption_type_list([result])
 
 
+@utils.arg('volume_type',
+           metavar='<volume_type>',
+           type=str,
+           help="Name or ID of the volume type")
+@utils.service_type('volumev2')
+def do_encryption_type_delete(cs, args):
+    """Delete the encryption type for a volume type (Admin Only)."""
+    volume_type = _find_volume_type(cs, args.volume_type)
+    cs.volume_encryption_types.delete(volume_type)
+
+
 def _print_qos_specs(qos_specs):
     utils.print_dict(qos_specs._info)
 
